@@ -2354,6 +2354,7 @@ func (*ConvertUsingExpr) iExpr()  {}
 func (*MatchExpr) iExpr()         {}
 func (*GroupConcatExpr) iExpr()   {}
 func (*Default) iExpr()           {}
+func (*ObjectFieldAccess) iExpr() {}
 
 // ReplaceExpr finds the from expression from root
 // and replaces it with to. If from matches root,
@@ -2826,6 +2827,38 @@ func (node BoolVal) replace(from, to Expr) bool {
 	return false
 }
 
+// ObjectFieldAccess represents an object field access.
+type ObjectFieldAccess struct {
+	// Metadata is not populated by the parser.
+	// It's a placeholder for analyzers to store
+	// additional data, typically info about which
+	// table or column this node references.
+	Metadata interface{}
+	Object   Expr
+	Field    ColIdent
+}
+
+// Format formats the node.
+func (node *ObjectFieldAccess) Format(buf *TrackedBuffer) {
+	buf.Myprintf("%v.", node.Object)
+	buf.Myprintf("%v", node.Field)
+}
+
+func (node *ObjectFieldAccess) walkSubtree(visit Visit) error {
+	if node == nil {
+		return nil
+	}
+	return Walk(
+		visit,
+		node.Object,
+		node.Field,
+	)
+}
+
+func (node *ObjectFieldAccess) replace(from, to Expr) bool {
+	return false
+}
+
 // ColName represents a column name.
 type ColName struct {
 	// Metadata is not populated by the parser.
@@ -3391,12 +3424,11 @@ func (node *ConvertTypeSimple) walkSubtree(visit Visit) error {
 }
 
 type ConvertTypeList struct {
-	Element ConvertType
 }
 
 // Format formats the node.
 func (node *ConvertTypeList) Format(buf *TrackedBuffer) {
-	buf.Myprintf("[%s]", node.Element)
+	buf.Myprintf("[]")
 }
 
 func (node *ConvertTypeList) walkSubtree(visit Visit) error {
@@ -3405,57 +3437,23 @@ func (node *ConvertTypeList) walkSubtree(visit Visit) error {
 	}
 	return Walk(
 		visit,
-		node.Element,
 	)
 }
 
 type ConvertTypeObject struct {
-	Fields []*ConvertTypeObjectField
 }
 
 // Format formats the Object.
 func (node *ConvertTypeObject) Format(buf *TrackedBuffer) {
-	buf.Myprintf("{")
-	for i := range node.Fields {
-		buf.Myprintf("%s", node.Fields[i])
-		if i != len(node.Fields)-1 {
-			buf.Myprintf(", ")
-		}
-	}
-	buf.Myprintf("}")
+	buf.Myprintf("{}")
 }
 
 func (node *ConvertTypeObject) walkSubtree(visit Visit) error {
 	if node == nil {
 		return nil
 	}
-	nodes := make([]SQLNode, len(node.Fields))
-	for i := range node.Fields {
-		nodes[i] = node.Fields[i]
-	}
 	return Walk(
 		visit,
-		nodes...,
-	)
-}
-
-type ConvertTypeObjectField struct {
-	Name string
-	Type ConvertType
-}
-
-// Format formats the node.
-func (node *ConvertTypeObjectField) Format(buf *TrackedBuffer) {
-	buf.Myprintf("%s: %s", node.Name, node.Type)
-}
-
-func (node *ConvertTypeObjectField) walkSubtree(visit Visit) error {
-	if node == nil {
-		return nil
-	}
-	return Walk(
-		visit,
-		node.Type,
 	)
 }
 
